@@ -18,7 +18,7 @@
 
 #include "config.h"
 #include <glib.h>
-#include <glib/gi18n-lib.h>
+#include <glib/gi18n.h>
 #include <openssl/ssl.h>
 #include <openssl/err.h>
 #include "mn-ssl.h"
